@@ -7,18 +7,9 @@ def get_stellar_toml():
     .. _SEP-1: https://github.com/stellar/stellar-protocol/blob/master/ecosystem/sep-0001.md
     .. _`Account Info`: https://github.com/stellar/stellar-protocol/blob/master/ecosystem/sep-0001.md#account-information
 
-    Returns the default info for stellar.toml as a dictionary. Replace this
-    function with another by passing it to
-    :func:`polaris.integrations.register_integrations` like so:
-    ::
-
-        from myapp.integrations import get_toml_data
-
-        register_integrations(
-            deposit=DepositIntegration(),
-            withdrawal=WithdrawalIntegration(),
-            toml_func=get_toml_data
-        )
+    Replace this function with another by passing it to
+    ``register_integrations()`` as described in
+    :doc:`Registering Integrations</register_integrations/index>`.
 
     The function you pass to the `toml_func` parameter should return a
     dictionary containing any of the following top level keys:
@@ -34,7 +25,7 @@ def get_stellar_toml():
     """
     return {
         "CURRENCIES": [
-            {"code": asset.code, "issuer": settings.STELLAR_ISSUER_ACCOUNT_ADDRESS}
+            {"code": asset.code, "issuer": asset.issuer}
             for asset in Asset.objects.all().iterator()
         ]
     }
